#ifndef __PARAMS_H
#define __PARAMS_H
#include <stdio.h>

typedef enum {
    e_rw,
    e_ro
}AccessEnum;

typedef enum {
    e_signed = 0,
    e_unsigned = 1
}Signage;

typedef struct TypeDecl {
     AccessEnum access;
     Signage signage;
     char *typeName;
     int references;

///////////////////////////////////////////////
#if defined(__cplusplus) || defined(c_plusplus)
     void print( FILE *fp )
     {
        if( access == e_ro ) fprintf( fp, "const " );
        if( signage == e_unsigned ) fprintf( fp, "unsigned " );
     	fprintf(fp, "%s ", typeName );
	for( int i = 0; i < references; i++ )
	    fprintf(fp, "*" );
     }

     char *decl_str( void )
     {
         static char buff[128];
	 sprintf( buff, "%s%s%s", 
		access == e_ro ? "const " : "", 
		signage == e_unsigned ? "unsigned " : "",
		typeName );
	 for( int i = 0; i < references; i++ )
	     strcat( buff, "*" );

	return buff;
     }

     char *var_str( void )
     {
         static char buff[128];
	 sprintf( buff, "%s%s%s", 
		access == e_ro ? "const_" : "", 
		signage == e_unsigned ? "unsigned_":"",
		typeName );
	 for( int i = 0; i < references; i++ )
	     strcat( buff, "_ptr" );

	 return buff;
     }

     bool isVoid( void ) 
     { 
         if( typeName == 0 ) return true;
         return !strcmp( typeName, "void" ); 
     }

     bool operator == ( TypeDecl &t )
     {
         if( access == t.access  && 
	     signage == t.signage &&
	   !strcmp( typeName, t.typeName ) && 
	    references == t.references )
	     return true;
	else
	     return false;
     }
#endif
///////////////////////////////////////////////

}TypeDecl;

typedef struct _param{
    TypeDecl *td;
    char *name;
    struct _param *next;

///////////////////////////////////////////////
#if defined(__cplusplus) || defined(c_plusplus)
    void print( FILE*fp )
    {
        td->print(fp);
	if( name != NULL )
	fprintf(fp, "%s", name );
    }

    void printType( FILE *fp )
    {
        td->print(fp);
    }

    void printName( FILE *fp )
    {
    	if( name != NULL )
        fprintf(fp, "%s", name );
    }
#endif
///////////////////////////////////////////////

}Param;

typedef struct _func_decl{
    TypeDecl *td;
    char *name;
    Param *params;
    Param *bound_params;
    struct _func_decl *next;

///////////////////////////////////////////////
#if defined(__cplusplus) || defined(c_plusplus)
    int nparams( void )
    {
        int n = 0 ;
	for( Param *cursor = params; cursor; cursor = cursor->next )
	{
	    if( cursor->td->isVoid() )	continue;
	    n++;
	}
	return n;
    }

    void print( FILE *fp )
    {
        td->print( fp );
	if( bound_params != 0L )
	    fprintf( fp, " (*" );
	fprintf(fp,      " %s(", name );
	for( Param *cursor = params; cursor; cursor = cursor->next )
	{
	    fprintf(fp,  " " );
	    cursor->print(fp);
	    if( cursor->next )
	    	fprintf(fp, "," );
        }
	fprintf( fp, " )" );

	if( bound_params != 0L )
	{
	    fprintf(fp, ")(" );
	    for( Param *cursor = bound_params; cursor; cursor = cursor->next )
	    {
	        fprintf(fp, " " );
		cursor->print(fp);
		if( cursor->next )
		    fprintf(fp, "," );
	    }
	    fprintf(fp, ")" );
	}
	fprintf(fp, "\n" );
    }

    void printFunctionCaller(FILE *fp)
    {
        if( !td->isVoid() )
	    fprintf(fp, "return " );
        fprintf(fp, "((" );
	td->print(fp);
	fprintf(fp, "(*)(" );
	Param *cursor;
	for( cursor = params; cursor; cursor = cursor->next )
	{
	    cursor->printType(fp);
	    if( cursor->next ) fprintf(fp, ", " );
	}
	fprintf(fp, "))fptrs[e_%s])(", name );
	for( cursor = params; cursor; cursor = cursor->next )
	{
	    cursor->printName(fp);
	    if( cursor->next ) fprintf(fp, ", " );
	}
	fprintf(fp, " );\n" );

    }
#endif
///////////////////////////////////////////////

}FunctionDecl;

#endif
