%token TYPEDEF
%token UNSIGNED
%token SIGNED
%token VOID
%token CHAR
%token SHORT
%token INT
%token LONG
%token FLOAT
%token DOUBLE
%token STRING
%token CONST
%token STRUCT
%token EXTERN

%union {
    char *string;
    int integer;
    float real;
};

%type <string> name name_opt
%type <integer> access type base_type signage

%{
#include <stdlib.h>
#include <malloc.h>
#include <stdio.h>
#include <string.h>
#include "params.h"

extern void eat_block( void );
#ifdef __linux
extern char *yytext;
#else
extern char yytext[];
#endif
static FunctionDecl *funcs = 0L;
static FunctionDecl *current_func = 0L;
static TypeDecl *current_td = 0L;
static Param *current_params = 0L;
static int references;

FunctionDecl *parse(void);
static void yyerror( char *msg );

//////////////////////////// TYPES /////////////////////

#define MAX_TYPES 256

enum TypeEnum {
    e_VOID,
    e_CHAR,
    e_SHORT,
    e_INT,
    e_LONG,
    e_FLOAT,
    e_DOUBLE,
    e_STRUCT,
};


typedef struct { 
    char *name;
    int designation;
}Type;

static Type types[MAX_TYPES];
static int ntypes = 0;
static int types_inited = 0;

static int init_types( void );
void add_type( char *str );
int check_type( char *str );
char *get_type_name( int designation );
%}
%%

decls : decl | decls decl;

decl : typedef | function_decl ;


function_decl : extern type_decl binding_begin name 
	{
	    FunctionDecl *temp = (FunctionDecl *)malloc(sizeof( FunctionDecl));
	    temp->td = 0L;
	    temp->name = 0L;
	    temp->params = 0L;
	    temp->bound_params = 0L;
	    temp->next = 0L;

	    current_params = 0;

	    if( funcs == 0L )
	        funcs = current_func = temp; 
	    else
	    {
	    	current_func->next = temp;
		current_func = current_func->next;
	    }

	    current_func->td = current_td;
	    current_func->name = (char *)$4;
	}
	'(' params ')' binding_end ';' ; 

extern : 
	| EXTERN
	;

 
params : param | params ',' param;

param : type_decl name_opt
	{
	    Param *param = (Param *)malloc( sizeof( Param ));
	    param->td = current_td;
	    param->name = (char *)$2;
	    param->next = 0L;

	    if( current_params == 0 )
	    {
	        current_params = param;
	    }
	    else
	    {
	        Param *cursor;
		for( cursor = current_params; cursor->next != 0L; cursor = cursor->next )
			;
		cursor->next = param;
	    }
	};

type_decl : access signage type 
	{
	    current_td = (TypeDecl *)malloc( sizeof( TypeDecl ));
	    current_td->access = (AccessEnum)$1;
	    current_td->signage = (Signage)$2;
	    current_td->typeName = get_type_name( $3 );
	    references = 0;
	} 
	reference
	{
	    current_td->references = references;
	};

binding_begin : 
	| '(' '*' ;

binding_end : 
	{
	    current_func->params = current_params;
	    current_params = 0L;
	}
	| ')' 
	{
	    current_func->params = current_params;
	    current_params = 0L;
	}
	'(' params ')'
	{
	    current_func->bound_params = current_params;
	    current_params = 0L;
	}

access : 
	/* empty */ { $$ = e_rw; }
	|CONST { $$ = e_ro; }

reference :
	/* empty */ { references = 0; }
	| '*'       { references++; }
	| '*' reference { references++; }


name_opt :
	/* empty - must be of type void */ { $$ = 0L; }
	| name { $$ = $1; }

type : base_type 
       | STRING
       {
            if( ($$ = (int)check_type( yytext )) < 0 )
	    {
	        yyerror( "Invalid type" );
		return -1;
	    }
       };


typedef : TYPEDEF signage type reference name ';'
	  {
	      add_type( (char *)$5 );
	      free( $5 );
	  }
	;

signage :  { $$ = 0; }
	| UNSIGNED
	  { $$ = 1; }
	| SIGNED
	  { $$ = 0; }
	;

base_type : 
	  VOID    { $$ = e_VOID; }
	| CHAR    { $$ = e_CHAR; }
	| SHORT   { $$ = e_SHORT; }
	| INT     { $$ = e_INT; }
	| LONG    { $$ = e_LONG; }
	| FLOAT   { $$ = e_FLOAT; }
	| DOUBLE  { $$ = e_DOUBLE; }
	| SHORT INT { $$ = e_SHORT; }
	| LONG INT { $$ = e_LONG; }
	| struct { $$ = e_STRUCT; }
	;

struct : STRUCT struct_def

struct_def : name
	{
	    free( $1 );
	}
	| name_opt '{' 
	{ 
	    eat_block(); 
	}

name : STRING
	{
	    $$ =  strdup(yytext);
	}

%%

FunctionDecl *parse(void)
{
    yyparse();
    return funcs;
}

static void yyerror( char *msg )
{
    extern int yylineno;
    fprintf(stderr, "%s line %d near \"%s\".\n", msg, yylineno, yytext );
}

//////////////////////////// TYPES /////////////////////

static int init_types( void )
{
    types_inited = 1;

    types[ntypes].name = strdup( "void" );
    types[ntypes].designation = e_VOID; 
    ntypes++;
    types[ntypes].name = strdup( "char" );
    types[ntypes].designation = e_CHAR;
    ntypes++;
    types[ntypes].name = strdup( "short" );
    types[ntypes].designation = e_SHORT;
    ntypes++;
    types[ntypes].name = strdup( "int" );
    types[ntypes].designation = e_INT;
    ntypes++;
    types[ntypes].name = strdup( "long" );
    types[ntypes].designation = e_LONG;
    ntypes++;
    types[ntypes].name = strdup( "float" );
    types[ntypes].designation = e_FLOAT;
    ntypes++;
    types[ntypes].name = strdup( "double" );
    types[ntypes].designation = e_DOUBLE;
    ntypes++;

    return types_inited;
}

void add_type( char *str )
{
    types_inited || init_types();

    if( ntypes >= MAX_TYPES )
    {
        fprintf( stderr, "Internal error : Out of types\n" );
	exit(1);
    }
    types[ntypes].name = strdup( str );
    types[ntypes].designation = ntypes << 8;
    ntypes++;
}

int check_type( char *str )
{
    int i;
    for( i = 0; i < ntypes; i++ )
    {
        if( !strcmp( types[i].name, str ))
	    return types[i].designation;
    }
    return -1;
}

char *get_type_name( int designation )
{
    int i;
    for( i = 0; i < ntypes; i++ )
    {
        if( designation == types[i].designation )
	    return types[i].name;
    }
    return 0L;
}

/////////////////////////// TYPES /////////////////////
