#include <list>
#include <stdio.h>
#include <assert.h>
#include "params.h"

using namespace std;

extern "C" FunctionDecl *parse( void );

void print_file( FILE *ofp, char *file )
{
    FILE *fp = fopen( file, "r" );
    char buff[256];
    if( fp == NULL )
    {
	fprintf( stderr, "Parser : print_file - Unable to open file \"%s\"\n", file );
	exit(1);
    }
    while( fgets( buff, sizeof( buff ), fp ) )
	fputs( buff, ofp );
    fclose( fp );
}


static void print_gl_h( FunctionDecl *funcs )
{
    FILE *fp = fopen( "_gl.h", "w+" );
    assert( fp );

    print_file( fp, "srcfiles/_gl.h_1" );

    fprintf( fp,    "typedef enum {\n" );

    FunctionDecl *cursor;
    int flag = 0;
    for( cursor = funcs; cursor; cursor = cursor->next )
    {
	if( flag == 0 && !strncmp( cursor->name, "glX", 3 ) )
	{
	    fprintf(fp, 
		    "\n"
		    "    e_endGL,\n"
		    "\n" );
	    flag = 1;
	}
        fprintf(fp, "    e_%s,\n", cursor->name );
    }
    fprintf(fp,     "    e_END\n"
                   "}OglFuncNum;\n"
                   "\n\n" );

    fprintf(fp,    "static char *_ogl_func_names[] = { \n" );

    flag = 0;
    for( cursor = funcs; cursor; cursor = cursor->next )
    {
  	if( flag == 0 && !strncmp( cursor->name, "glX", 3 ))
	{
	    fprintf( fp,
		   "    \"\",\n" );
	    flag = 1;
	}
        fprintf(fp,"    \"%s\",\n", cursor->name );
    }
    fprintf(fp,    "};\n" );

    print_file( fp, "srcfiles/_gl.h_2" );

    fclose( fp );
}

static void print_gl_c( FunctionDecl *funcs )
{
    FunctionDecl *cursor;
    FILE *fp = fopen( "_gl.c", "w+" );
    assert( fp );

    print_file( fp, "srcfiles/_gl.c_1" );

    for( cursor = funcs; cursor; cursor = cursor->next )
    {
        int np = cursor->nparams();
	int i;
	fprintf(fp, "\n" );

	cursor->print( fp );

	fprintf(fp, "{\n"
	            "    inited || init(); \n"
	            "    if( callback != 0L )\n"
		    "    {\n" );
	fprintf(fp, "        di.name    = \"%s\";\n", cursor->name );
	fprintf(fp, "        di.func    = e_%s;\n"  , cursor->name );
	fprintf(fp, "        di.nparams = %d;\n"    , np );



	i = 0;
	Param *p;
	for( p = cursor->params; p; p = p->next )
	{
	    if( p->td->isVoid() ) continue;

	    fprintf(fp,
	            "        di.params[%d].name = \"%s\";\n", i, p->name );
	    fprintf(fp, 
	            "        di.params[%d].type = e_%s;\n", i, p->td->var_str());

            // There is one silly exception to be handled here
	    // const GLXContext gc	
	    if( !strcmp( p->td->typeName, "GLXContext" ) && p->td->access == e_ro )
	        fprintf(fp,
	    	    "        di.params[%d].val.GLXContext_val = %s;\n", i, p->name );
	    else
	        fprintf(fp,
	    	    "        di.params[%d].val.%s_val = %s;\n", i, p->td->var_str(), p->name );
	    i++;
	}


	fprintf(fp, "        callback( &di );\n"
		    "    }\n");
	fprintf(fp, "    " );

	// Add some specialized code to key on a frame in glXSwapBuffers().
	if( !strcmp( cursor->name, "glXSwapBuffers" ) )
	    print_file( fp, "srcfiles/_gl.c_2" );

	cursor->printFunctionCaller( fp );
	fprintf(fp, "}\n" );
     }
     fclose(fp);
}

static void print_dump_h( FunctionDecl *f )
{

    list <TypeDecl>plist;
    FunctionDecl *cursor;
    for( cursor = f; cursor; cursor = cursor->next )
    {
	for( Param *p = cursor->params; p; p = p->next )
	{
	    if( p->td->isVoid() )
	    	continue;

	    int found = 0;
	    list <TypeDecl>::iterator pi;
	    for( pi = plist.begin(); pi != plist.end(); pi++ )
	    {
	        if( (*pi) == (*p->td) )
		{
		    found = 1;
		    break;
		}
	    }
	    if( !found )
	    	plist.push_back( (*p->td) );
	}
    }

    list <TypeDecl>::iterator pi;
    FILE *fp = fopen( "ogldump.h", "w+" );
    assert( fp );
    print_file( fp, "srcfiles/ogldump.h_1" );

    fprintf(fp,     "typedef union {\n" );
    for( pi = plist.begin(); pi != plist.end(); pi++ )
    {
        fprintf(fp, "    %20s  %20s_val;\n", (*pi).decl_str(), (*pi).var_str() );
    }
    fprintf(fp,     "}Val;\n"
    		    "\n\n"
    		    "typedef enum {\n" );

    for( pi = plist.begin(); pi != plist.end(); pi++ )
        fprintf(fp, "    e_%s,\n", (*pi).var_str() );

    fprintf(fp,     "}TypeNum;\n" );

#if 0
    fprintf(fp,     "\n\n"
    		    "    switch( type )\n"
            	    "    {\n" ); 

    for( pi = plist.begin(); pi != plist.end(); pi++ )
    {
        fprintf(fp, "        case e_%s :\n", (*pi).var_str() );
	fprintf(fp, "            printf( \"%%d\", val.%s_val );\n", (*pi).var_str() ); 
	fprintf(fp, "            break;\n" );
    }

    fprintf(fp,     "    }\n" );
#endif

    print_file( fp, "srcfiles/ogldump.h_2" );

    fclose( fp );
}

    struct Vals {
        char *name;
	char *val;
    };

static void print_dump_c( FunctionDecl *f )
{
    FILE *fp = fopen( "ogldump.c", "w+" );
    assert( fp );

    print_file( fp, "srcfiles/ogldump.c_1" );

    FILE *glfp = fopen( "/usr/include/GL/gl.h", "r" );
    assert( glfp );

    char buff[256];
    list <Vals> bits;
    list <Vals> enums;

    while( fgets( buff, sizeof( buff ), glfp ))
    {
        if( strncmp( buff, "#define", strlen( "#define" ) ) ) 
	    continue;

	char define[128];
	char name[128];
	char val[128];

	if( sscanf( buff, "%s %s %s", define, name, val )  != 3 )
	    continue;

	if( strncmp( val, "0x", 2 ))
	    continue;

	Vals *_val = new Vals;
	_val->name = strdup( name );
	_val->val = strdup( val );

	if( strlen(name) > 4 && !strncmp( &name[strlen(name)-4], "BITS", 4 ) )
	   continue; 


	if( strlen(name) > 3 && !strncmp( &name[strlen(name)-3], "BIT", 3 ) )
	    bits.push_back( *_val );
	else
	    enums.push_back( *_val );

    }
    fclose( glfp );

    fprintf( fp,     "static struct _enum_table{\n"
		     "    GLenum val;\n"
		     "    char *str;\n"
		     "}EnumTable[] = {\n" );

    list<Vals>::iterator p;
    for( p = enums.begin(); p != enums.end(); p++ )
        fprintf( fp, "    { %s, \"%s\" },\n", p->val, p->name );
    fprintf( fp,     "};\n" );

    fprintf( fp,     "\n\n"
    		     "static struct _bitfield_table{\n"
		     "    GLbitfield bits;\n"
		     "    char *str;\n"
		     "}BitFieldTable[] = {\n" );

    for( p = bits.begin(); p != bits.end(); p++ )
        fprintf( fp, "    { %s, \"%s\" },\n", p->val, p->name );
    fprintf( fp,     "};\n"
                     "\n\n" );


    print_file( fp, "srcfiles/ogldump.c_2" );

    fclose( fp );
}



static void remove_duplicates( FunctionDecl *f )
{
    FunctionDecl *c1 = f;
    FunctionDecl *c2;

    for( c1 = f; c1->next; c1 = c1->next )
    {
        for( c2 = c1; c2->next; c2 = c2->next )
	{
	    if( !strcmp( c1->name, c2->next->name ) )
	    {
	    	fprintf( stderr, "Warning : duplicate entry \"%s\" .. removing.\n", c1->name );
	        c2->next = c2->next->next;
	    }
	        
	}
    }

}

int main( int argc, char **argv )
{
    FunctionDecl *f = parse();
    assert( f );

    remove_duplicates( f );

    print_gl_h( f );
    print_gl_c( f );
    print_dump_h( f );
    print_dump_c( f );
    return 0;
}
