#include <stdio.h>
#include <ctype.h>

typedef struct _range{
    int low, high;
    struct _range *next;
}Range;

static Range *_current_range = 0L;
static Range *_list_of_ranges = 0L;

static void add_range( int low, int high )
{
    Range *cursor;
    Range *r;

    if( high < low )
    {
        int temp = low;
	low = high;
	high = temp;
    }

    r = (Range *)malloc( sizeof( Range )); 
    r->low = low;
    r->high = high;
    r->next = 0L;
    if( _list_of_ranges == 0L )
    {
        _list_of_ranges = r;
    }
    else
    {
        if( r->low < _list_of_ranges->low )
	{
	    r->next = _list_of_ranges;
	    _list_of_ranges = r;
	}
	else
	{
	    int placed = 0;
            for( cursor = _list_of_ranges; 
	         cursor->next; cursor = cursor->next )
	    {
	        if( r->low < cursor->next->low )
		{
		    r->next = cursor->next;
		    cursor->next = r;
		    placed = 1;
		}
	    }
	    if( !placed ) 
		cursor->next = r;
	}
    }
}


int inRange( int n )
{
    if( _current_range == 0L )
        return 0;

    if( n < _current_range->low )
    	return 0;

    while( n > _current_range->high )
    {
    	_current_range = _current_range->next;
	return inRange( n );
    }

    return 1;
}

static void throw_error( const char *str, const char *p )
{
    int i;
    fprintf( stderr, 
      "Parse error in range string :\n"
      "    %s\n", str );
    for( i = 0; i < 4 + ((int)p-(int)str); i++ )
        fprintf( stderr, "-" );
    fprintf( stderr, "^\n" );

    exit(1);
}

static int range( char **_p )
{
    int low, high;
    char *p = *_p;

    if( !isdigit(*p) )
    	return 0;

    low = atoi(p);
    high = low;

    while( *p && isdigit(*p) )
    	p++;

    if( *p == 0L || *p == ',' ) 
    {
        add_range( low, high );
	*_p = p;
	return 1;
    }

    if( *p == '-' )
       p++;

    if( !isdigit(*p) )
    {
        *_p = p;
    	return 0;
    }

    high = atoi( p );
    add_range( low, high );

    while( *p && isdigit(*p) )
    	p++;

    *_p = p;

    return 1;
}

void parseRanges( char *str )
{
    char *p = str;
    while( *p )
    {
        if( !range(&p) ) 
            throw_error( str, p );

        if( *p == 0L ) 
	    break;

        else if( *p == ',' )
        {
            p++;
	    continue;
        }
    }

    _current_range = _list_of_ranges;

}


void print_em(void)
{
    Range *cursor;

    printf( "Ranges :\n" );
    for( cursor = _list_of_ranges; cursor; cursor = cursor->next )
        printf( "%d - %d\n", cursor->low, cursor->high );
}
