
/**********************************************************************

 Function, parameter_index, val, next, [nextval, next, nextval, ... ]

//////////////////////// GRAMMAR    ////////////////////////////////

all : FUNCTION_ENUM, PARAMETER_INDEX, val, END=-1
val : POSITIVE_NUMBER | ZERO  |  NEGATIVE_NUMBER | NEGATIVE_NUMBER, references
references : reference | references, reference
reference  : CONDITION_CONSTANT, CONDITIONAL_VAL | ZERO, CONDITIONAL_CONSTANT

////////////////////////////////////////////////////////////////////

Example :

1. 
e_glColor3bv, 0, 3, -1  = FUNCTION_ENUM (e_glColor3bv), PARAMETER_INDEX (0), POSITIVE_NUMBER (3), END (-1)
    number of elements in array = 3, print 
     for( i = 0; i < 3; i++ )
	(GLbyte *)parameter[PARAMETER_INDEX][i]

2. 
e_glGetBooleanv, 1, 0, -1 = FUNCTION_ENUM (e_glGetBooleanv), PARAMTER_INDEX (1), ZERO (0), END (-1)

   number of elementes in array : Don't know, print 0x<address) or <ptr>

3. 
e_glPixelMapfv, 2, -1, -1  = FUNCTION_ENUM (e_glGetBooleanv) PARAMETER_INDEX (2), NEGATIVE_NUMBER (-1), END (-1)
    number of elements in array = paramter[PARAMTER_INDEX + NEGATIVE_NUMBER].val 

4.
e_glLightModeliv, 1, -1, 
		GL_LIGHT_MODEL_AMBIENT, 4, 
		GL_LIGHT_MODEL_LOCAL_VIEWER, 1, 
		GL_LIGHT_MODEL_TWO_SIDE, 1, -1

FUNCTION_ENUM (e_glLightModeliv), PARAMTER_INDEX (1), NEGATIVE_NUMBER(-11),
		CONDITION_CONSTANT (GL_LIGHT_MODEL_AMBIENT), CONDITION_VAL (4)
		CONDITION_CONSTANT (GL_LIGHT_MODEL_LOCAL_VIEWER), CONDITION_VAL (1)
		CONDITION_CONSTANT (GL_LIGHT_MODEL_TWO_SIDE), CONDITION_VAL (1) END(-1)

    number of elements in array = 
	parameter[PARAMETER_INDEX + NEGATIVE_NUMBER].val == GL_LIGHT_MODEL_AMBIENT ? 4 :
	parameter[PARAMETER_INDEX + NEGATIVE_NUMBER].val == GL_LIGHT_MODEL_LOCAL_VIEWER ? 1 :
	parameter[PARAMETER_INDEX + NEGATIVE_NUMBER].val == GL_LIGHT_MODEL_TWO_SIDE ? 1 : 0 (Dont know)

5. 

glTexEnvfv, 2, -1,
	GL_TEXTURE_ENV_MODE, 1,
	0, 4, -1,

FUNCTION_ENUM (e_glTexEnvfv), PARAMETER_INDEX (2), NEGATIVE_NUMBER (-1),
		CONDITION_CONSTANT (GLTEXTURE_ENV_MODE), CONDITION_VAL (1),
		ZERO(0 = Else), CONDITIONAL_VAL (4), END (-1)
	number of elements in array = 
		parameter[PARAMETER_INDEX + NEGATIVE_NUMBER].val == GLTEXTURE_ENV_MODE : 4

**********************************************************************/


static int vector_size_tokens[] = {
    e_glColor3bv, 0, 3, -1,
    e_glColor3dv, 0, 3, -1,
    e_glColor3fv, 0, 3, -1,
    e_glColor3iv, 0, 3, -1,
    e_glColor3sv, 0, 3, -1,
    e_glColor3ubv, 0, 3, -1,
    e_glColor3uiv, 0, 3, -1,
    e_glColor3usv, 0, 3, -1,
    e_glColor4bv,  0, 4, -1,
    e_glColor4dv,  0, 4, -1,
    e_glColor4fv,  0, 4, -1,
    e_glColor4iv,  0, 4, -1,
    e_glColor4sv,  0, 4, -1,
    e_glColor4ubv,  0, 4, -1,
    e_glColor4uiv,  0, 4, -1,
    e_glColor4usv,  0, 4, -1,

#if 0 // Seems to have disappeared in 1.2
#if defined (__sgi) // [
    e_glColorTableParameterfvSGI, 2, 4, -1,
    e_glColorTableParameterivSGI, 2, 4, -1,
    e_glConvolutionParameterfvEXT, 2, -1, 
		GL_CONVOLUTION_BORDER_MODE_EXT, 1, 
		0, 4, -1, 
#endif // ]
#endif
#if defined (__sgi) // [
    e_glConvolutionParameterivEXT, 2, -1, 
		GL_CONVOLUTION_BORDER_MODE_EXT, 1, 
		0, 4, -1,
#endif // ]
    e_glEdgeFlagv, 0, 1, -1,
    e_glEvalCoord1dv, 0, 1, -1,
    e_glEvalCoord1fv, 0, 1, -1,
    e_glEvalCoord2dv, 0, 2, -1,
    e_glEvalCoord2fv, 0, 2, -1,
    e_glFogfv, 1, -1, 
		GL_FOG_COLOR, 4, 
#if defined (__sgi) // [
		GL_FOG_OFFSET_VALUE_SGIX, 4, 
#endif // ]
		0, 1, -1,
    e_glFogiv, 1, -1, 
		GL_FOG_COLOR, 4, 
#if defined (__sgi) // [
		GL_FOG_OFFSET_VALUE_SGIX, 4, 
#endif // ]
		0, 1, -1,
    e_glGetBooleanv, 1, 0, -1,	// DONT KNOW - long
    e_glGetDoublev, 1, 0, -1,	// DONT KNOW - long
    e_glGetFloatv, 1, 0, -1,	// DONT KNOW - long
    e_glGetIntegerv, 1, 0, -1,	// DONT KNOW - long

#if defined (__sgi) // [
    e_glGetConvolutionParameterfvEXT, 2, -1,
		GL_CONVOLUTION_BORDER_MODE_EXT, 1, 
		GL_CONVOLUTION_FILTER_SCALE_EXT, 4,
		GL_CONVOLUTION_FILTER_BIAS_EXT, 4,
		GL_CONVOLUTION_FORMAT_EXT, 1,	
		GL_CONVOLUTION_WIDTH_EXT, 1,
		GL_CONVOLUTION_HEIGHT_EXT, 1,
		GL_MAX_CONVOLUTION_WIDTH_EXT, 1,
		GL_MAX_CONVOLUTION_HEIGHT_EXT, 1, -1,
    e_glGetConvolutionParameterivEXT, 2, -1,
		GL_CONVOLUTION_BORDER_MODE_EXT, 1, 
		GL_CONVOLUTION_FILTER_SCALE_EXT, 4,
		GL_CONVOLUTION_FILTER_BIAS_EXT, 4,
		GL_CONVOLUTION_FORMAT_EXT, 1,	
		GL_CONVOLUTION_WIDTH_EXT, 1,
		GL_CONVOLUTION_HEIGHT_EXT, 1,
		GL_MAX_CONVOLUTION_WIDTH_EXT, 1,
		GL_MAX_CONVOLUTION_HEIGHT_EXT, 1, -1,
    e_glGetHistogramParameterfvEXT, 2, 1, -1,
    e_glGetHistogramParameterivEXT, 2, 1, -1,
#endif // ]
    e_glGetLightfv, 2, -1,
		GL_AMBIENT, 4, 
		GL_DIFFUSE, 4, 
		GL_SPECULAR, 4, 
		GL_POSITION, 4, 
		GL_SPOT_DIRECTION, 3, 
		GL_SPOT_EXPONENT, 1, 
		GL_SPOT_CUTOFF, 1, 
		GL_CONSTANT_ATTENUATION, 1, 
		GL_CONSTANT_ATTENUATION, 1, 
		GL_CONSTANT_ATTENUATION, 1, -1,
    e_glGetLightiv, 2, -1,
		GL_AMBIENT, 4, 
		GL_DIFFUSE, 4, 
		GL_SPECULAR, 4, 
		GL_POSITION, 4, 
		GL_SPOT_DIRECTION, 3, 
		GL_SPOT_EXPONENT, 1, 
		GL_SPOT_CUTOFF, 1, 
		GL_CONSTANT_ATTENUATION, 1, 
		GL_CONSTANT_ATTENUATION, 1, 
		GL_CONSTANT_ATTENUATION, 1, -1,
#if defined (__sgi) // [
    e_glGetListParameterfvSGIX, 2, 1, -1,
    e_glGetListParameterivSGIX, 2, 1, -1,
#endif // ]
    e_glGetMapdv, 2, -1,
		GL_COEFF, 0,	// DONT KNOW - Needs to know "order" from glGetMapdv( ..., GL_ORDER)
		GL_ORDER, -1, 
			GL_MAP1_COLOR_4, 1,
			GL_MAP1_INDEX, 1,
			GL_MAP1_NORMAL, 1,
			GL_MAP1_TEXTURE_COORD_1, 1,
			GL_MAP1_TEXTURE_COORD_2, 1,
			GL_MAP1_TEXTURE_COORD_3, 1,
			GL_MAP1_TEXTURE_COORD_4, 1,
			GL_MAP1_VERTEX_3, 1,
			GL_MAP1_VERTEX_4, 1,
			GL_MAP2_COLOR_4, 2,
			GL_MAP2_INDEX, 2,
			GL_MAP2_NORMAL, 2,
			GL_MAP2_TEXTURE_COORD_1, 2,
			GL_MAP2_TEXTURE_COORD_2, 2,
			GL_MAP2_TEXTURE_COORD_3, 2,
			GL_MAP2_TEXTURE_COORD_4, 2,
			GL_MAP2_VERTEX_3, 2,
			GL_MAP2_VERTEX_4, 2,
		GL_DOMAIN, -1,
			GL_MAP1_COLOR_4, 2,
			GL_MAP1_INDEX, 2,
			GL_MAP1_NORMAL, 2,
			GL_MAP1_TEXTURE_COORD_1, 2,
			GL_MAP1_TEXTURE_COORD_2, 2,
			GL_MAP1_TEXTURE_COORD_3, 2,
			GL_MAP1_TEXTURE_COORD_4, 2,
			GL_MAP1_VERTEX_3, 2,
			GL_MAP1_VERTEX_4, 2,
			GL_MAP2_COLOR_4, 4,
			GL_MAP2_INDEX, 4,
			GL_MAP2_NORMAL, 4,
			GL_MAP2_TEXTURE_COORD_1, 4,
			GL_MAP2_TEXTURE_COORD_2, 4,
			GL_MAP2_TEXTURE_COORD_3, 4,
			GL_MAP2_TEXTURE_COORD_4, 4,
			GL_MAP2_VERTEX_3, 4,
			GL_MAP2_VERTEX_4, 4,
	 	-1,

    e_glGetMapfv, 2, -1,
		GL_COEFF, 0,	// DONT KNOW - Needs to know "order" from glGetMapdv( ..., GL_ORDER)
		GL_ORDER, -1, 
			GL_MAP1_COLOR_4, 1,
			GL_MAP1_INDEX, 1,
			GL_MAP1_NORMAL, 1,
			GL_MAP1_TEXTURE_COORD_1, 1,
			GL_MAP1_TEXTURE_COORD_2, 1,
			GL_MAP1_TEXTURE_COORD_3, 1,
			GL_MAP1_TEXTURE_COORD_4, 1,
			GL_MAP1_VERTEX_3, 1,
			GL_MAP1_VERTEX_4, 1,
			GL_MAP2_COLOR_4, 2,
			GL_MAP2_INDEX, 2,
			GL_MAP2_NORMAL, 2,
			GL_MAP2_TEXTURE_COORD_1, 2,
			GL_MAP2_TEXTURE_COORD_2, 2,
			GL_MAP2_TEXTURE_COORD_3, 2,
			GL_MAP2_TEXTURE_COORD_4, 2,
			GL_MAP2_VERTEX_3, 2,
			GL_MAP2_VERTEX_4, 2,
		GL_DOMAIN, -1,
			GL_MAP1_COLOR_4, 2,
			GL_MAP1_INDEX, 2,
			GL_MAP1_NORMAL, 2,
			GL_MAP1_TEXTURE_COORD_1, 2,
			GL_MAP1_TEXTURE_COORD_2, 2,
			GL_MAP1_TEXTURE_COORD_3, 2,
			GL_MAP1_TEXTURE_COORD_4, 2,
			GL_MAP1_VERTEX_3, 2,
			GL_MAP1_VERTEX_4, 2,
			GL_MAP2_COLOR_4, 4,
			GL_MAP2_INDEX, 4,
			GL_MAP2_NORMAL, 4,
			GL_MAP2_TEXTURE_COORD_1, 4,
			GL_MAP2_TEXTURE_COORD_2, 4,
			GL_MAP2_TEXTURE_COORD_3, 4,
			GL_MAP2_TEXTURE_COORD_4, 4,
			GL_MAP2_VERTEX_3, 4,
			GL_MAP2_VERTEX_4, 4,
	 	-1,
    e_glGetMapiv, 2, -1,
		GL_COEFF, 0,	// DONT KNOW - Needs to know "order" from glGetMapdv( ..., GL_ORDER)
		GL_ORDER, -1, 
			GL_MAP1_COLOR_4, 1,
			GL_MAP1_INDEX, 1,
			GL_MAP1_NORMAL, 1,
			GL_MAP1_TEXTURE_COORD_1, 1,
			GL_MAP1_TEXTURE_COORD_2, 1,
			GL_MAP1_TEXTURE_COORD_3, 1,
			GL_MAP1_TEXTURE_COORD_4, 1,
			GL_MAP1_VERTEX_3, 1,
			GL_MAP1_VERTEX_4, 1,
			GL_MAP2_COLOR_4, 2,
			GL_MAP2_INDEX, 2,
			GL_MAP2_NORMAL, 2,
			GL_MAP2_TEXTURE_COORD_1, 2,
			GL_MAP2_TEXTURE_COORD_2, 2,
			GL_MAP2_TEXTURE_COORD_3, 2,
			GL_MAP2_TEXTURE_COORD_4, 2,
			GL_MAP2_VERTEX_3, 2,
			GL_MAP2_VERTEX_4, 2,
		GL_DOMAIN, -1,
			GL_MAP1_COLOR_4, 2,
			GL_MAP1_INDEX, 2,
			GL_MAP1_NORMAL, 2,
			GL_MAP1_TEXTURE_COORD_1, 2,
			GL_MAP1_TEXTURE_COORD_2, 2,
			GL_MAP1_TEXTURE_COORD_3, 2,
			GL_MAP1_TEXTURE_COORD_4, 2,
			GL_MAP1_VERTEX_3, 2,
			GL_MAP1_VERTEX_4, 2,
			GL_MAP2_COLOR_4, 4,
			GL_MAP2_INDEX, 4,
			GL_MAP2_NORMAL, 4,
			GL_MAP2_TEXTURE_COORD_1, 4,
			GL_MAP2_TEXTURE_COORD_2, 4,
			GL_MAP2_TEXTURE_COORD_3, 4,
			GL_MAP2_TEXTURE_COORD_4, 4,
			GL_MAP2_VERTEX_3, 4,
			GL_MAP2_VERTEX_4, 4,
	 	-1,
    e_glGetMaterialfv, 2, -1,
		GL_AMBIENT, 4,
		GL_DIFFUSE, 4,
		GL_SPECULAR, 4,
		GL_EMISSION, 4,
		GL_SHININESS, 1,
		GL_COLOR_INDEXES, 3, -1,

    e_glGetMaterialiv, 2, -1,
		GL_AMBIENT, 4,
		GL_DIFFUSE, 4,
		GL_SPECULAR, 4,
		GL_EMISSION, 4,
		GL_SHININESS, 1,
		GL_COLOR_INDEXES, 3, -1,

#if defined( __sgi )
    e_glGetMinmaxParameterfvEXT, 2, 1, -1,
    e_glGetMinmaxParameterivEXT, 2, 1, -1,
#endif
    e_glGetPixelMapfv, 1, 0, -1,	// DONT KNOW
    e_glGetPixelMapuiv, 1, 0, -1,	// DONT KNOW
    e_glGetPixelMapusv, 1, 0, -1,	// DONT KNOW

    e_glGetPointerv, 1, 1, -1,
#if 0
    e_glGetPointervEXT, 1, 1, -1,
#endif
    e_glGetTexEnvfv, 2, -1, 
		GL_TEXTURE_ENV_MODE, 1,
		GL_TEXTURE_ENV_COLOR, 4,
#if defined (__sgi) // [
		GL_TEXTURE_ENV_BIAS_SGIX, 4,
#endif // ]
		-1,
    e_glGetTexEnviv, 2, -1, 
		GL_TEXTURE_ENV_MODE, 1,
		GL_TEXTURE_ENV_COLOR, 4,
#if defined (__sgi) // [
		GL_TEXTURE_ENV_BIAS_SGIX, 4,
#endif // ]
		-1,
    e_glGetTexGendv, 2, -1,
		GL_TEXTURE_GEN_MODE, 1,
		GL_OBJECT_PLANE, 4,
		GL_EYE_PLANE, 4,
		-1,
    e_glGetTexGenfv, 2, -1,
		GL_TEXTURE_GEN_MODE, 1,
		GL_OBJECT_PLANE, 4,
		GL_EYE_PLANE, 4,
		-1,
    e_glGetTexGeniv, 2, -1,
		GL_TEXTURE_GEN_MODE, 1,
		GL_OBJECT_PLANE, 4,
		GL_EYE_PLANE, 4,
		-1,
    e_glGetTexLevelParameterfv, 3, 1, -1,
    e_glGetTexLevelParameteriv, 3, 1, -1,
    e_glGetTexParameterfv, 2, -1,
		GL_TEXTURE_MAG_FILTER, 1,
		GL_TEXTURE_MIN_FILTER, 1,
		GL_TEXTURE_WRAP_S, 1,
		GL_TEXTURE_WRAP_T, 1,

#if defined (__sgi) // [
		GL_TEXTURE_WRAP_R_EXT, 1,
#endif // ]
		GL_TEXTURE_BORDER_COLOR, 4,
#if defined (__sgi) // [
		GL_DETAIL_TEXTURE_LEVEL_SGIS, 1,
		GL_DETAIL_TEXTURE_MODE_SGIS, 1,
		GL_DETAIL_TEXTURE_FUNC_POINTS_SGIS, 1,
		GL_SHARPEN_TEXTURE_FUNC_POINTS_SGIS, 1,
		GL_POST_TEXTURE_FILTER_BIAS_SGIX, 4,
		GL_POST_TEXTURE_FILTER_SCALE_SGIX, 4,
		GL_TEXTURE_PRIORITY_EXT, 1,
		GL_TEXTURE_RESIDENT_EXT, 1,
		GL_TEXTURE_MIN_LOD_SGIS, 1,
		GL_TEXTURE_MAX_LOD_SGIS, 1,
		GL_TEXTURE_BASE_LEVEL_SGIS, 1,
		GL_TEXTURE_MAX_LEVEL_SGIS, 1,
		GL_DUAL_TEXTURE_SELECT_SGIS, 1,
		GL_QUAD_TEXTURE_SELECT_SGIS, 1,
		GL_TEXTURE_FILTER4_SIZE_SGIS, 1,
		GL_TEXTURE_CLIPMAP_FRAME_SGIX, 1,
		GL_TEXTURE_CLIPMAP_CENTER_SGIX, 2,
		GL_TEXTURE_CLIPMAP_OFFSET_SGIX, 2,
		GL_TEXTURE_COMPARE_SGIX, 1,
		GL_TEXTURE_COMPARE_OPERATOR_SGIX, 1,
		GL_SHADOW_AMBIENT_SGIX, 1,
#endif // ]
		-1,


    e_glGetTexParameteriv, 2, -1,
		GL_TEXTURE_MAG_FILTER, 1,
		GL_TEXTURE_MIN_FILTER, 1,
		GL_TEXTURE_WRAP_S, 1,
		GL_TEXTURE_WRAP_T, 1,
#if defined (__sgi) // [
		GL_TEXTURE_WRAP_R_EXT, 1,
#endif // ]
		GL_TEXTURE_BORDER_COLOR, 4,
#if defined (__sgi) // [
		GL_DETAIL_TEXTURE_LEVEL_SGIS, 1,
		GL_DETAIL_TEXTURE_MODE_SGIS, 1,
		GL_DETAIL_TEXTURE_FUNC_POINTS_SGIS, 1,
		GL_SHARPEN_TEXTURE_FUNC_POINTS_SGIS, 1,
		GL_POST_TEXTURE_FILTER_BIAS_SGIX, 4,
		GL_POST_TEXTURE_FILTER_SCALE_SGIX, 4,
		GL_TEXTURE_PRIORITY_EXT, 1,
		GL_TEXTURE_RESIDENT_EXT, 1,
		GL_TEXTURE_MIN_LOD_SGIS, 1,
		GL_TEXTURE_MAX_LOD_SGIS, 1,
		GL_TEXTURE_BASE_LEVEL_SGIS, 1,
		GL_TEXTURE_MAX_LEVEL_SGIS, 1,
		GL_DUAL_TEXTURE_SELECT_SGIS, 1,
		GL_QUAD_TEXTURE_SELECT_SGIS, 1,
		GL_TEXTURE_FILTER4_SIZE_SGIS, 1,
		GL_TEXTURE_CLIPMAP_FRAME_SGIX, 1,
		GL_TEXTURE_CLIPMAP_CENTER_SGIX, 2,
		GL_TEXTURE_CLIPMAP_OFFSET_SGIX, 2,
		GL_TEXTURE_COMPARE_SGIX, 1,
		GL_TEXTURE_COMPARE_OPERATOR_SGIX, 1,
		GL_SHADOW_AMBIENT_SGIX, 1,
#endif // ]
		-1,
    e_glIndexdv, 0, 1, -1,
    e_glIndexfv, 0, 1, -1,
    e_glIndexiv, 0, 1, -1,
    e_glIndexsv, 0, 1, -1,
    e_glIndexubv, 0, 1, -1,
    e_glLightModelfv, 1, -1, 
		GL_LIGHT_MODEL_AMBIENT, 4, 
		GL_LIGHT_MODEL_LOCAL_VIEWER, 1, 
		GL_LIGHT_MODEL_TWO_SIDE, 1, -1,
    e_glLightModeliv, 1, -1, 
		GL_LIGHT_MODEL_AMBIENT, 4, 
		GL_LIGHT_MODEL_LOCAL_VIEWER, 1, 
		GL_LIGHT_MODEL_TWO_SIDE, 1, -1,
    e_glLightfv, 2, -1, 
		GL_AMBIENT, 4, 
		GL_DIFFUSE, 4, 
		GL_SPECULAR, 4, 
		GL_POSITION, 4, 
		GL_SPOT_DIRECTION, 3, 
		GL_SPOT_EXPONENT, 1, 
		GL_SPOT_CUTOFF, 1, 
		GL_CONSTANT_ATTENUATION, 1, 
		GL_CONSTANT_ATTENUATION, 1, 
		GL_CONSTANT_ATTENUATION, 1, -1,
    e_glLightiv, 2, -1, 
		GL_AMBIENT, 4, 
		GL_DIFFUSE, 4, 
		GL_SPECULAR, 4, 
		GL_POSITION, 4, 
		GL_SPOT_DIRECTION, 3, 
		GL_SPOT_EXPONENT, 1, 
		GL_SPOT_CUTOFF, 1, 
		GL_CONSTANT_ATTENUATION, 1, 
		GL_CONSTANT_ATTENUATION, 1, 
		GL_CONSTANT_ATTENUATION, 1, -1,
/* No documentation		
#if defined (__sgi) // [
    e_glListParameterfvSGIX
    e_glListParameterivSGIX
#endif // ]
*/
    e_glMaterialfv, 2, -1, 
		GL_AMBIENT, 4,
		GL_DIFFUSE, 4,
		GL_SPECULAR, 4,
		GL_EMISSION, 4,
		GL_SHININESS, 1,
		GL_AMBIENT_AND_DIFFUSE, 4,
		GL_COLOR_INDEXES, 3, -1,

    e_glMaterialiv, 2, -1,
		GL_AMBIENT, 4,
		GL_DIFFUSE, 4,
		GL_SPECULAR, 4,
		GL_EMISSION, 4,
		GL_SHININESS, 1,
		GL_AMBIENT_AND_DIFFUSE, 4,
		GL_COLOR_INDEXES, 3, -1,
    e_glNormal3bv, 0, 3, -1,
    e_glNormal3dv, 0, 3, -1,
    e_glNormal3fv, 0, 3, -1,
    e_glNormal3iv, 0, 3, -1,
    e_glNormal3sv, 0, 3, -1,
    e_glPixelMapfv, 2, -1, -1,
    e_glPixelMapuiv, 2, -1, -1,
    e_glPixelMapusv, 2, -1, -1,

#if 0 // Seems to have disappeared in 1.2
#if defined (__sgi) // [
    e_glPixelTransformParameterfvSGI, 2, 0, -1, // DONT KNOW - no documentation
    e_glPixelTransformParameterivSGI, 2, 0, -1, // DONT KNOW - no documentation
    e_glPointParameterfvSGIS, 1, -1, 
		GL_POINT_SIZE_MIN_SGIS, 1,
		GL_POINT_SIZE_MAX_SGIS, 1,
		GL_POINT_FADE_THRESHOLD_SIZE_SGIS, 1,
		GL_DISTANCE_ATTENUATION_SGIS, 3, -1,
#endif // ]
#endif
    e_glRasterPos2dv, 0, 2, -1,
    e_glRasterPos2fv, 0, 2, -1,
    e_glRasterPos2iv, 0, 2, -1,
    e_glRasterPos2sv, 0, 2, -1,
    e_glRasterPos3dv, 0, 3, -1,
    e_glRasterPos3fv, 0, 3, -1,
    e_glRasterPos3iv, 0, 3, -1,
    e_glRasterPos3sv, 0, 3, -1,
    e_glRasterPos4dv, 0, 4, -1,
    e_glRasterPos4fv, 0, 4, -1,
    e_glRasterPos4iv, 0, 4, -1,
    e_glRasterPos4sv, 0, 4, -1,
    e_glRectdv, 0, 2, -1,
    e_glRectdv, 1, 2, -1,
    e_glRectfv, 0, 2, -1,
    e_glRectfv, 1, 2, -1,
    e_glRectiv, 0, 2, -1,
    e_glRectiv, 1, 2, -1,
    e_glRectsv, 0, 2, -1,
    e_glRectsv, 1, 2, -1,
#if defined (__sgi) // [
    e_glSpriteParameterfvSGIX, 1, 4, -1,
    e_glSpriteParameterivSGIX, 1, 4, -1,
#endif // ]
    e_glTexCoord1dv, 0, 1, -1,
    e_glTexCoord1fv, 0, 1, -1,
    e_glTexCoord1iv, 0, 1, -1,
    e_glTexCoord1sv, 0, 1, -1,
    e_glTexCoord2dv, 0, 2, -1,
    e_glTexCoord2fv, 0, 2, -1,
    e_glTexCoord2iv, 0, 2, -1,
    e_glTexCoord2sv, 0, 2, -1,
    e_glTexCoord3dv, 0, 3, -1,
    e_glTexCoord3fv, 0, 3, -1,
    e_glTexCoord3iv, 0, 3, -1,
    e_glTexCoord3sv, 0, 3, -1,
    e_glTexCoord4dv, 0, 4, -1,
    e_glTexCoord4fv, 0, 4, -1,
    e_glTexCoord4iv, 0, 4, -1,
    e_glTexCoord4sv, 0, 4, -1,
    e_glTexEnvfv, 2, -1,
	GL_TEXTURE_ENV_MODE, 1,
	0, 4, -1,
    e_glTexEnviv, 2, -1,
	GL_TEXTURE_ENV_MODE, 1,
	0, 4, -1,
    e_glTexGendv, 2, -1,
	GL_TEXTURE_GEN_MODE, 1,
	0, 4, -1,
    e_glTexGenfv, 2, -1,
	GL_TEXTURE_GEN_MODE, 1,
	0, 4, -1,
    e_glTexGeniv, 2, -1,
	GL_TEXTURE_GEN_MODE, 1,
	0, 4, -1,

    e_glTexParameterfv, 2, -1,
		GL_TEXTURE_MAG_FILTER, 1,
		GL_TEXTURE_MIN_FILTER, 1,
		GL_TEXTURE_WRAP_S, 1,
		GL_TEXTURE_WRAP_T, 1,
#if defined (__sgi) // [
		GL_TEXTURE_WRAP_R_EXT, 1,
#endif // ]
		GL_TEXTURE_BORDER_COLOR, 4,
#if defined (__sgi) // [
		GL_DETAIL_TEXTURE_LEVEL_SGIS, 1,
		GL_DETAIL_TEXTURE_MODE_SGIS, 1,
		GL_DETAIL_TEXTURE_FUNC_POINTS_SGIS, 1,
		GL_SHARPEN_TEXTURE_FUNC_POINTS_SGIS, 1,
		GL_POST_TEXTURE_FILTER_BIAS_SGIX, 4,
		GL_POST_TEXTURE_FILTER_SCALE_SGIX, 4,
		GL_TEXTURE_PRIORITY_EXT, 1,
		GL_TEXTURE_RESIDENT_EXT, 1,
		GL_TEXTURE_MIN_LOD_SGIS, 1,
		GL_TEXTURE_MAX_LOD_SGIS, 1,
		GL_TEXTURE_BASE_LEVEL_SGIS, 1,
		GL_TEXTURE_MAX_LEVEL_SGIS, 1,
		GL_DUAL_TEXTURE_SELECT_SGIS, 1,
		GL_QUAD_TEXTURE_SELECT_SGIS, 1,
		GL_TEXTURE_FILTER4_SIZE_SGIS, 1,
		GL_TEXTURE_CLIPMAP_FRAME_SGIX, 1,
		GL_TEXTURE_CLIPMAP_CENTER_SGIX, 2,
		GL_TEXTURE_CLIPMAP_OFFSET_SGIX, 2,
		GL_TEXTURE_COMPARE_SGIX, 1,
		GL_TEXTURE_COMPARE_OPERATOR_SGIX, 1,
		GL_SHADOW_AMBIENT_SGIX, 1,
#endif // ]
		-1,
    e_glTexParameteriv, 2, -1,
		GL_TEXTURE_MAG_FILTER, 1,
		GL_TEXTURE_MIN_FILTER, 1,
		GL_TEXTURE_WRAP_S, 1,
		GL_TEXTURE_WRAP_T, 1,
#if defined (__sgi) // [
		GL_TEXTURE_WRAP_R_EXT, 1,
#endif // ]
		GL_TEXTURE_BORDER_COLOR, 4,
#if defined (__sgi) // [
		GL_DETAIL_TEXTURE_LEVEL_SGIS, 1,
		GL_DETAIL_TEXTURE_MODE_SGIS, 1,
		GL_DETAIL_TEXTURE_FUNC_POINTS_SGIS, 1,
		GL_SHARPEN_TEXTURE_FUNC_POINTS_SGIS, 1,
		GL_POST_TEXTURE_FILTER_BIAS_SGIX, 4,
		GL_POST_TEXTURE_FILTER_SCALE_SGIX, 4,
		GL_TEXTURE_PRIORITY_EXT, 1,
		GL_TEXTURE_RESIDENT_EXT, 1,
		GL_TEXTURE_MIN_LOD_SGIS, 1,
		GL_TEXTURE_MAX_LOD_SGIS, 1,
		GL_TEXTURE_BASE_LEVEL_SGIS, 1,
		GL_TEXTURE_MAX_LEVEL_SGIS, 1,
		GL_DUAL_TEXTURE_SELECT_SGIS, 1,
		GL_QUAD_TEXTURE_SELECT_SGIS, 1,
		GL_TEXTURE_FILTER4_SIZE_SGIS, 1,
		GL_TEXTURE_CLIPMAP_FRAME_SGIX, 1,
		GL_TEXTURE_CLIPMAP_CENTER_SGIX, 2,
		GL_TEXTURE_CLIPMAP_OFFSET_SGIX, 2,
		GL_TEXTURE_COMPARE_SGIX, 1,
		GL_TEXTURE_COMPARE_OPERATOR_SGIX, 1,
		GL_SHADOW_AMBIENT_SGIX, 1,
#endif // ]
		-1,
    e_glVertex2dv, 0, 2, -1,
    e_glVertex2fv, 0, 2, -1,
    e_glVertex2iv, 0, 2, -1,
    e_glVertex2sv, 0, 2, -1,
    e_glVertex3dv, 0, 3, -1,
    e_glVertex3fv, 0, 3, -1,
    e_glVertex3iv, 0, 3, -1,
    e_glVertex3sv, 0, 3, -1,
    e_glVertex4dv, 0, 4, -1,
    e_glVertex4fv, 0, 4, -1,
    e_glVertex4iv, 0, 4, -1,
    e_glVertex4sv, 0, 4, -1,

    e_END
};


